<a name=""></a>
#  (2018-04-17)



<a name="0.1.0"></a>
# [0.1.0](https://github.com/viasite/site-discovery/compare/0.0.9...0.1.0) (2018-04-17)


### Features

* cache-time option ([cad3ae6](https://github.com/viasite/site-discovery/commit/cad3ae6))
* line output format, friendly for console and grep ([66e19a5](https://github.com/viasite/site-discovery/commit/66e19a5))



<a name="0.0.9"></a>
## [0.0.9](https://github.com/viasite/site-discovery/compare/0.0.8...0.0.9) (2018-03-07)



<a name="0.0.8"></a>
## [0.0.8](https://github.com/viasite/site-discovery/compare/0.0.7...0.0.8) (2018-02-22)


### Bug Fixes

* openpyxl 2.5 compatibility ([2b67a43](https://github.com/viasite/site-discovery/commit/2b67a43))
* try to open ([f55e759](https://github.com/viasite/site-discovery/commit/f55e759))



<a name="0.0.7"></a>
## [0.0.7](https://github.com/viasite/site-discovery/compare/0.0.6...0.0.7) (2018-01-11)



<a name="0.0.6"></a>
## [0.0.6](https://github.com/viasite/site-discovery/compare/0.0.5...0.0.6) (2018-01-11)


### Features

* server-info ([cf2d1be](https://github.com/viasite/site-discovery/commit/cf2d1be))



<a name="0.0.5"></a>
## [0.0.5](https://github.com/viasite/site-discovery/compare/0.0.4...0.0.5) (2017-11-27)



<a name="0.0.4"></a>
## [0.0.4](https://github.com/viasite/site-discovery/compare/0.0.3...0.0.4) (2017-11-27)


### Bug Fixes

* correct pypi install ([a62daf9](https://github.com/viasite/site-discovery/commit/a62daf9))



<a name="0.0.3"></a>
## [0.0.3](https://github.com/viasite/site-discovery/compare/0.0.2...0.0.3) (2017-11-27)


### Bug Fixes

* autosum was recursive ([3678f55](https://github.com/viasite/site-discovery/commit/3678f55))



<a name="0.0.2"></a>
## [0.0.2](https://github.com/viasite/site-discovery/compare/0.0.1...0.0.2) (2017-11-26)



<a name="0.0.1"></a>
## [0.0.1](https://github.com/viasite/site-discovery/compare/7094f0a...0.0.1) (2017-11-26)


### Bug Fixes

* create package site_discovery, translate comments to english ([7094f0a](https://github.com/viasite/site-discovery/commit/7094f0a))


### Features

* pip, setup.py, requirements ([ac1b48e](https://github.com/viasite/site-discovery/commit/ac1b48e))



